==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/include/mysql/components/services/psi_error_service.h <==
/* Copyright (c) 2017, 2019, Oracle and/or its affiliates. All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2.0,
as published by the Free Software Foundation.

This program is also distributed with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have included with MySQL.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License, version 2.0, for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef COMPONENTS_SERVICES_PSI_ERROR_SERVICE_H
#define COMPONENTS_SERVICES_PSI_ERROR_SERVICE_H

#include <mysql/components/service.h>
#include <mysql/components/services/psi_error_bits.h>

BEGIN_SERVICE_DEFINITION(psi_error_v1)
/** @sa log_error_v1_t. */
log_error_v1_t log_error;
END_SERVICE_DEFINITION(psi_error_v1)

#define REQUIRES_PSI_ERROR_SERVICE REQUIRES_SERVICE(psi_error_v1)

#endif /* COMPONENTS_SERVICES_PSI_ERROR_SERVICE_H */

==> mysql-8.0_8.0.44.orig.tar.gz: mysql-8.0.44/include/mysql/components/services/psi_error_service.h <==
/* Copyright (c) 2017, 2025, Oracle and/or its affiliates.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2.0,
as published by the Free Software Foundation.

This program is designed to work with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have either included with
the program or referenced in the documentation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License, version 2.0, for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef COMPONENTS_SERVICES_PSI_ERROR_SERVICE_H
#define COMPONENTS_SERVICES_PSI_ERROR_SERVICE_H

#include <mysql/components/service.h>
#include <mysql/components/services/bits/psi_error_bits.h>

BEGIN_SERVICE_DEFINITION(psi_error_v1)
/** @sa log_error_v1_t. */
log_error_v1_t log_error;
END_SERVICE_DEFINITION(psi_error_v1)

#endif /* COMPONENTS_SERVICES_PSI_ERROR_SERVICE_H */
